@@ -2,7 +2,6 @@ package HTML::Shakan::Field;
 use strict;
 use warnings;
 use Mouse;
-use HTML::Shakan::Utils;
 
 has id => (
     is => 'rw',
@@ -152,11 +151,11 @@ This is parameter filters in arrayref.
 
 For example, following field removes white space from parameter value in head and end.
 
-	TextField(
-		name     => 'f',
-		required => 1,
-		filters  => [qw'WhiteSpace']
-	),
+    TextField(
+        name     => 'f',
+        required => 1,
+        filters  => [qw'WhiteSpace']
+    ),
 
 =item widget
 
